Module dmidecode::bios[][src]

BIOS Information

Includes information about Type 0 and BIOS Type 13 SMBIOS structures

Structs

Bios

BIOS Information (Type 0)

BiosLanguage

BIOS Language Information (Type 13)

BiosRevision

BIOS Revision assembled from System BIOS Major Release and System BIOS Minor Release fields

Characteristics

BIOS Characteristics

CharacteristicsExtension1

BIOS Characteristics Extension Byte 1 layout. This information, available for SMBIOS 946 version 2.1 and later, appears at offset 12h within the BIOS Information structure.

CharacteristicsExtension2

BIOS Characteristics for Extension Byte 2 layout. This information, available for 950 SMBIOS version 2.4 and later, appears at offset 13h within the BIOS Information structure.

FirmwareRevision

Firmware Revision assembled from Embedded Controller Firmware Major Release and Embedded Controller Firmware Minor Release fields

InstallableLanguages

An iterator through available languages. Each available language has a description string.

LanguageFlags

BIOS Language flags

RomSize

The size of the physical device containing the BIOS.