Handle Bit Field values in SMBIOS structure

Due to SMBIOS information has read-only nature and Bit Field flags has text description it is reasonable to have special type(s) to handle them

Structs

Handles single flag within Bit Field

An iterator through all items in Bit Field layout

Flag position (index) in Bit Field

An iterator returns ranges of reserved bits folded from Iter

Reserved bits range

An iterator through setted non-reserved flags

Enums

There are 2 types of Bit Field flag meaningful and reserved for some purposes

Traits

Trait for Bit Field data

Type Definitions

Alias to Bit Field description “table”