Struct dmidecode::enclosure::Enclosure[][src]

pub struct Enclosure<'buffer> {
    pub handle: u16,
    pub manufacturer: &'buffer str,
    pub chassis_lock: bool,
    pub enclosure_type: EnclosureType,
    pub version: &'buffer str,
    pub serial_number: &'buffer str,
    pub asset_tag_number: &'buffer str,
    pub boot_up_state: Option<State>,
    pub power_supply_state: Option<State>,
    pub thermal_state: Option<State>,
    pub security_status: Option<SecurityStatus>,
    pub oem_defined: Option<u32>,
    pub height: Option<u8>,
    pub power_cords_number: Option<u8>,
    pub contained_elements: Option<ContainedElements<'buffer>>,
    pub sku_number: Option<&'buffer str>,
}

System Enclosure or Chassis structure

Fields

handle: u16

Specifies the structure’s handle

manufacturer: &'buffer str

Manufacturer string is non-null

chassis_lock: bool

Chassis lock is present

enclosure_type: EnclosureType

Type field identifies the type of enclosure. (Unknown is disallowed.)

version: &'buffer str

Version

serial_number: &'buffer str

Serial Number

asset_tag_number: &'buffer str

Asset Tag Number

boot_up_state: Option<State>

State of the enclosure when it was last booted;

power_supply_state: Option<State>

State of the enclosure’s power supply (or supplies) when last booted

thermal_state: Option<State>

Thermal state of the enclosure when last booted

security_status: Option<SecurityStatus>

Physical security status of the enclosure when last booted

oem_defined: Option<u32>

OEM- or BIOS vendor-specific information

height: Option<u8>

Height of the enclosure , in ’U’s A U is a standard unit of measure for the height of a rack or rack-mountable component and is equal to 1.75 inches or 4.445 cm. A value of 00h indicates that the enclosure height is unspecified.

power_cords_number: Option<u8>

Number of power cords associated with the enclosure or chassis A value of 00h indicates that the number is unspecified.

contained_elements: Option<ContainedElements<'buffer>>

Each Contained Element record consists of sub-fields that further describe elements contained by the chassis

sku_number: Option<&'buffer str>

Number of null-terminated string describing the chassis or enclosure SKU number