Baseboard (or Module) Information (Type 2)

The information in this structure defines attributes of a system baseboard (for example, a motherboard, planar, server blade, or other standard system module).

Structs

The BaseBoard table defined in the SMBIOS specification.

The baseboard characteristic flags defined in the SMBIOS specification.

Enums

The baseboard type defined in the SMBIOS specification.