pub struct BaseBoard<'buffer> {
    pub handle: u16,
    pub manufacturer: &'buffer str,
    pub product: &'buffer str,
    pub version: &'buffer str,
    pub serial: &'buffer str,
    pub asset: Option<&'buffer str>,
    pub feature_flags: Option<BaseBoardFlags>,
    pub location_in_chassis: Option<&'buffer str>,
    pub chassis_handle: Option<u16>,
    pub board_type: Option<BoardType>,
}
The BaseBoard table defined in the SMBIOS specification.

Optional fields will only be set if the version of the parsed SMBIOS table is high enough to have defined the field.

Fields

handle: u16manufacturer: &'buffer strproduct: &'buffer strversion: &'buffer strserial: &'buffer strasset: Option<&'buffer str>feature_flags: Option<BaseBoardFlags>location_in_chassis: Option<&'buffer str>chassis_handle: Option<u16>board_type: Option<BoardType>