Enum dmidecode::structures::cache::SystemCacheType
source · pub enum SystemCacheType {
Other,
Unknown,
Instruction,
Data,
Unified,
Undefined(u8),
}Expand description
The cache type for a cache level (L1, L2, L3, …) is type 03h (Instruction) when all the caches at that level are Instruction caches. The cache type for a specific cache level (L1, L2, L3, …) is type 04h (Data) when all the caches at that level are Data caches. The cache type for a cache level (L1, L2, L3, …) is type 05h (Unified) when the caches at that level are a mix of Instruction and Data caches.
Variants