Module memory_array_mapped_address

Module memory_array_mapped_address 

Memory Array Mapped Address (Type 19)

This structure provides the address mapping for a Physical Memory Array. One structure is present for each contiguous address range described.

Structs

MemoryArrayMappedAddress
Main struct for Memory Array Mapped Address (Type 19)