Module memory_device

Memory Device (Type 17)

This structure describes a single memory device that is part of a larger Physical Memory Array (Type 16) structure.

Structs

Detail
The memory device details
MemoryDevice
The Memory Device table defined in the SMBIOS specification.
OperatingModes

Enums

ErrorGranularity
ErrorOperation
ErrorType
FormFactor
MemoryTechnology
Type