Memory Device Mapped Address (Type 20)
This structure maps memory address space usually to a device-level granularity.
One structure is present for each contiguous address range described.
Structs
- Main struct for Memory Device Mapped Address (Type 20)