pub struct PortConnector<'a> {
    pub handle: u16,
    pub internal_reference_designator: &'a str,
    pub internal_connector_type: ConnectorType,
    pub external_reference_designator: &'a str,
    pub external_connector_type: ConnectorType,
    pub port_type: PortType,
}
The Port Connector Information table defined in the SMBIOS specification.

Optional fields will only be set if the version of the parsed SMBIOS table is high enough to have defined the field.

Fields

handle: u16

Specifies the structure’s handle

internal_reference_designator: &'a str

Internal Reference Designator, that is, internal to the system enclosure
EXAMPLE: ‘J101’, 0

internal_connector_type: ConnectorType

Internal Connector type

external_reference_designator: &'a str

String number for the External Reference Designation external to the system enclosure
EXAMPLE: ‘COM A’, 0

external_connector_type: ConnectorType

External Connector type

port_type: PortType

Describes the function of the port