ProcessorFamily

Enum ProcessorFamily 

pub enum ProcessorFamily {
Show 222 variants Other, Unknown, Intel8086, Intel80286, Intel386Processor, Intel486Processor, Intel8087, Intel80287, Intel80387, Intel80487, IntelPentiumProcessor, PentiumProProcessor, PentiumIIProcessor, PentiumProcessorWithMMXTechnology, IntelCeleronProcessor, PentiumIIXeonProcessor, PentiumIIIProcessor, M1Family, M2Family, IntelCeleronMProcessor, IntelPentium4HTProcessor, AMDDuronProcessorFamily, K5Family, K6Family, K62, K63, AMDAthlonProcessorFamily, AMD29000Family, K62Plus, PowerPCFamily, PowerPC601, PowerPC603, PowerPC603Plus, PowerPC604, PowerPC620, PowerPCX704, PowerPC750, IntelCoreDuoProcessor, IntelCoreDuoMobileProcessor, IntelCoreSoloMobileProcessor, IntelAtomProcessor, IntelCoreMProcessor, IntelCoreM3Processor, IntelCoreM5Processor, IntelCoreM7Processor, AlphaFamily, Alpha21064, Alpha21066, Alpha21164, Alpha21164PC, Alpha21164a, Alpha21264, Alpha21364, AMDTurionIIUltraDualCoreMobileMProcessorFamily, AMDTurionIIDualCoreMobileMProcessorFamily, AMDAthlonIIDualCoreMProcessorFamily, AMDOpteron6100SeriesProcessor, AMDOpteron4100SeriesProcessor, AMDOpteron6200SeriesProcessor, AMDOpteron4200SeriesProcessor, AMDFXSeriesProcessor, MIPSFamily, MIPSR4000, MIPSR4200, MIPSR4400, MIPSR4600, MIPSR10000, AMDCSeriesProcessor, AMDESeriesProcessor, AMDASeriesProcessor, AMDGSeriesProcessor, AMDZSeriesProcessor, AMDRSeriesProcessor, AMDOpteron4300SeriesProcessor, AMDOpteron6300SeriesProcessor, AMDOpteron3300SeriesProcessor, AMDFireProSeriesProcessor, SPARCFamily, SuperSPARC, MicroSPARCII, MicroSPARCIIep, UltraSPARC, UltraSPARCII, UltraSPARCIii, UltraSPARCIII, UltraSPARCIIIi, Motorola68040Family, Motorola68xxx, Motorola68000, Motorola68010, Motorola68020, Motorola68030, AMDAthlonX4QuadCoreProcessorFamily, AMDOpteronX1000SeriesProcessor, AMDOpteronX2000SeriesAPU, AMDOpteronASeriesProcessor, AMDOpteronX3000SeriesAPU, AMDZenProcessorFamily, HobbitFamily, CrusoeTM5000Family, CrusoeTM3000Family, EfficeonTM8000Family, Weitek, AvailableForAssignment, ItaniumProcessor, AMDAthlon64ProcessorFamily, AMDOpteronProcessorFamily, AMDSempronProcessorFamily, AMDTurion64MobileTechnology, DualCoreAMDOpteronProcessorFamily, AMDAthlon64X2DualCoreProcessorFamily, AMDTurion64X2MobileTechnology, QuadCoreAMDOpteronProcessorFamily, ThirdGenerationAMDOpteronProcessorFamily, AMDPhenomFXQuadCoreProcessorFamily, AMDPhenomX4QuadCoreProcessorFamily, AMDPhenomX2DualCoreProcessorFamily, AMDAthlonX2DualCoreProcessorFamily, PARISCFamily, PARISC8500, PARISC8000, PARISC7300LC, PARISC7200, PARISC7100LC, PARISC7100, V30Family, QuadCoreIntelXeonProcessor3200Series, DualCoreIntelXeonProcessor3000Series, QuadCoreIntelXeonProcessor5300Series, DualCoreIntelXeonProcessor5100Series, DualCoreIntelXeonProcessor5000Series, DualCoreIntelXeonProcessorLV, DualCoreIntelXeonProcessorULV, DualCoreIntelXeonProcessor7100Series, QuadCoreIntelXeonProcessor5400Series, QuadCoreIntelXeonProcessor, DualCoreIntelXeonProcessor5200Series, DualCoreIntelXeonProcessor7200Series, QuadCoreIntelXeonProcessor7300Series, QuadCoreIntelXeonProcessor7400Series, MultiCoreIntelXeonProcessor7400Series, PentiumIIIXeonProcessor, PentiumIIIProcessorWithIntelSpeedStepTechnology, Pentium4Processor, IntelXeonProcessor, AS400Family, IntelXeonProcessorMP, AMDAthlonXPProcessorFamily, AMDAthlonMPProcessorFamily, IntelItanium2Processor, IntelPentiumMProcessor, IntelCeleronDProcessor, IntelPentiumDProcessor, IntelPentiumProcessorExtremeEdition, IntelCoreSoloProcessor, Ambiguous, IntelCore2DuoProcessor, IntelCore2SoloProcessor, IntelCore2ExtremeProcessor, IntelCore2QuadProcessor, IntelCore2ExtremeMobileProcessor, IntelCore2DuoMobileProcessor, IntelCore2SoloMobileProcessor, IntelCoreI7Processor, DualCoreIntelCeleronProcessor, IBM390Family, G4, G5, ESA390G6, ZArchitectureBase, IntelCoreI5Processor, IntelCoreI3Processor, IntelCoreI9Processor, VIAC7MProcessorFamily, VIAC7DProcessorFamily, VIAC7ProcessorFamily, VIAEdenProcessorFamily, MultiCoreIntelXeonProcessor, DualCoreIntelXeonProcessor3xxxSeries, QuadCoreIntelXeonProcessor3xxxSeries, VIANanoProcessorFamily, DualCoreIntelXeonProcessor5xxxSeries, QuadCoreIntelXeonProcessor5xxxSeries, DualCoreIntelXeonProcessor7xxxSeries, QuadCoreIntelXeonProcessor7xxxSeries, MultiCoreIntelXeonProcessor7xxxSeries, MultiCoreIntelXeonProcessor3400Series, AMDOpteron3000SeriesProcessor, AMDSempronIIProcessor, EmbeddedAMDOpteronQuadCoreProcessorFamily, AMDPhenomTripleCoreProcessorFamily, AMDTurionUltraDualCoreMobileProcessorFamily, AMDTurionDualCoreMobileProcessorFamily, AMDAthlonDualCoreProcessorFamily, AMDSempronSIProcessorFamily, AMDPhenomIIProcessorFamily, AMDAthlonIIProcessorFamily, SixCoreAMDOpteronProcessorFamily, AMDSempronMProcessorFamily, I860, I960, ARMv7, ARMv8, ARMv9, SH3, SH4, ARM, StrongARM, Cyrix6x86, MediaGX, MII, WinChip, DSP, VideoProcessor, RISCVRV32, RISCVRV64, RISCVRV128, Available(u16), NotUsed(u16), ForFutureUse, ProcessorFamily2, OutOfSpec,
}
For processor family enumerations from 0 to FDh, Processor Family is identical to Processor Family 2. For processor family enumerations from 100h to FFFDh, Processor Family has a value of FEh and Processor Family 2 has the enumerated value. The following values are reserved: • FFh Not used. FFh is the un-initialized value of Flash memory. • FFFFh Not used. FFFFh is the un-initialized value of Flash memory. • FFFEh For special use in the future, such as FEh as the extension indicator.

Variants



Other



Unknown



Intel8086



Intel80286



Intel386Processor



Intel486Processor



Intel8087



Intel80287



Intel80387



Intel80487



IntelPentiumProcessor



PentiumProProcessor



PentiumIIProcessor



PentiumProcessorWithMMXTechnology



IntelCeleronProcessor



PentiumIIXeonProcessor



PentiumIIIProcessor



M1Family



M2Family



IntelCeleronMProcessor



IntelPentium4HTProcessor



AMDDuronProcessorFamily

Note that the meaning associated with this value is different from the meaning defined in CIM_Processor.Family for the same value.



K5Family

Note that the meaning associated with this value is different from the meaning defined in CIM_Processor.Family for the same value.



K6Family

Note that the meaning associated with this value is different from the meaning defined in CIM_Processor.Family for the same value.



K62

Note that the meaning associated with this value is different from the meaning defined in CIM_Processor.Family for the same value.



K63

Note that the meaning associated with this value is different from the meaning defined in CIM_Processor.Family for the same value.



AMDAthlonProcessorFamily

Note that the meaning associated with this value is different from the meaning defined in CIM_Processor.Family for the same value.



AMD29000Family



K62Plus



PowerPCFamily



PowerPC601



PowerPC603



PowerPC603Plus



PowerPC604



PowerPC620



PowerPCX704



PowerPC750



IntelCoreDuoProcessor



IntelCoreDuoMobileProcessor



IntelCoreSoloMobileProcessor



IntelAtomProcessor



IntelCoreMProcessor



IntelCoreM3Processor



IntelCoreM5Processor



IntelCoreM7Processor



AlphaFamily

Some version 2.0 specification implementations used Processor Family type value 30h to represent a Pentium® Pro processor.



Alpha21064



Alpha21066



Alpha21164



Alpha21164PC



Alpha21164a



Alpha21264



Alpha21364



AMDTurionIIUltraDualCoreMobileMProcessorFamily



AMDTurionIIDualCoreMobileMProcessorFamily



AMDAthlonIIDualCoreMProcessorFamily



AMDOpteron6100SeriesProcessor



AMDOpteron4100SeriesProcessor



AMDOpteron6200SeriesProcessor



AMDOpteron4200SeriesProcessor



AMDFXSeriesProcessor



MIPSFamily



MIPSR4000



MIPSR4200



MIPSR4400



MIPSR4600



MIPSR10000



AMDCSeriesProcessor



AMDESeriesProcessor



AMDASeriesProcessor



AMDGSeriesProcessor



AMDZSeriesProcessor



AMDRSeriesProcessor



AMDOpteron4300SeriesProcessor



AMDOpteron6300SeriesProcessor



AMDOpteron3300SeriesProcessor



AMDFireProSeriesProcessor



SPARCFamily



SuperSPARC



MicroSPARCII



MicroSPARCIIep



UltraSPARC



UltraSPARCII



UltraSPARCIii



UltraSPARCIII



UltraSPARCIIIi



Motorola68040Family



Motorola68xxx



Motorola68000



Motorola68010



Motorola68020



Motorola68030



AMDAthlonX4QuadCoreProcessorFamily



AMDOpteronX1000SeriesProcessor



AMDOpteronX2000SeriesAPU



AMDOpteronASeriesProcessor



AMDOpteronX3000SeriesAPU



AMDZenProcessorFamily



HobbitFamily



CrusoeTM5000Family



CrusoeTM3000Family



EfficeonTM8000Family



Weitek



AvailableForAssignment



ItaniumProcessor



AMDAthlon64ProcessorFamily



AMDOpteronProcessorFamily



AMDSempronProcessorFamily



AMDTurion64MobileTechnology



DualCoreAMDOpteronProcessorFamily



AMDAthlon64X2DualCoreProcessorFamily



AMDTurion64X2MobileTechnology



QuadCoreAMDOpteronProcessorFamily



ThirdGenerationAMDOpteronProcessorFamily



AMDPhenomFXQuadCoreProcessorFamily



AMDPhenomX4QuadCoreProcessorFamily



AMDPhenomX2DualCoreProcessorFamily



AMDAthlonX2DualCoreProcessorFamily



PARISCFamily



PARISC8500



PARISC8000



PARISC7300LC



PARISC7200



PARISC7100LC



PARISC7100



V30Family



QuadCoreIntelXeonProcessor3200Series



DualCoreIntelXeonProcessor3000Series



QuadCoreIntelXeonProcessor5300Series



DualCoreIntelXeonProcessor5100Series



DualCoreIntelXeonProcessor5000Series



DualCoreIntelXeonProcessorLV



DualCoreIntelXeonProcessorULV



DualCoreIntelXeonProcessor7100Series



QuadCoreIntelXeonProcessor5400Series



QuadCoreIntelXeonProcessor



DualCoreIntelXeonProcessor5200Series



DualCoreIntelXeonProcessor7200Series



QuadCoreIntelXeonProcessor7300Series



QuadCoreIntelXeonProcessor7400Series



MultiCoreIntelXeonProcessor7400Series



PentiumIIIXeonProcessor



PentiumIIIProcessorWithIntelSpeedStepTechnology



Pentium4Processor



IntelXeonProcessor



AS400Family



IntelXeonProcessorMP



AMDAthlonXPProcessorFamily



AMDAthlonMPProcessorFamily



IntelItanium2Processor



IntelPentiumMProcessor



IntelCeleronDProcessor



IntelPentiumDProcessor



IntelPentiumProcessorExtremeEdition



IntelCoreSoloProcessor



Ambiguous

Version 2.5 of this specification listed this value as “available for assignment”. CIM_Processor.mof files assigned this value to AMD K7 processors in the CIM_Processor.Family property, and an SMBIOS change request assigned it to Intel Core 2 processors. Some implementations of the SMBIOS version 2.5 specification are known to use BEh to indicate Intel Core 2 processors. Some implementations of SMBIOS and some implementations of CIM-based software may also have used BEh to indicate AMD K7 processors.



IntelCore2DuoProcessor



IntelCore2SoloProcessor



IntelCore2ExtremeProcessor



IntelCore2QuadProcessor



IntelCore2ExtremeMobileProcessor



IntelCore2DuoMobileProcessor



IntelCore2SoloMobileProcessor



IntelCoreI7Processor



DualCoreIntelCeleronProcessor



IBM390Family



G4



G5



ESA390G6



ZArchitectureBase



IntelCoreI5Processor



IntelCoreI3Processor



IntelCoreI9Processor



VIAC7MProcessorFamily



VIAC7DProcessorFamily



VIAC7ProcessorFamily



VIAEdenProcessorFamily



MultiCoreIntelXeonProcessor



DualCoreIntelXeonProcessor3xxxSeries



QuadCoreIntelXeonProcessor3xxxSeries



VIANanoProcessorFamily



DualCoreIntelXeonProcessor5xxxSeries



QuadCoreIntelXeonProcessor5xxxSeries



DualCoreIntelXeonProcessor7xxxSeries



QuadCoreIntelXeonProcessor7xxxSeries



MultiCoreIntelXeonProcessor7xxxSeries



MultiCoreIntelXeonProcessor3400Series



AMDOpteron3000SeriesProcessor



AMDSempronIIProcessor



EmbeddedAMDOpteronQuadCoreProcessorFamily



AMDPhenomTripleCoreProcessorFamily



AMDTurionUltraDualCoreMobileProcessorFamily



AMDTurionDualCoreMobileProcessorFamily



AMDAthlonDualCoreProcessorFamily



AMDSempronSIProcessorFamily



AMDPhenomIIProcessorFamily



AMDAthlonIIProcessorFamily



SixCoreAMDOpteronProcessorFamily



AMDSempronMProcessorFamily



I860



I960



ARMv7



ARMv8



ARMv9



SH3



SH4



ARM



StrongARM



Cyrix6x86



MediaGX



MII



WinChip



DSP



VideoProcessor



RISCVRV32



RISCVRV64



RISCVRV128



Available(u16)



NotUsed(u16)



ForFutureUse



ProcessorFamily2



OutOfSpec