Struct dmidecode::baseboard::BaseBoard [−][src]
The BaseBoard table defined in the SMBIOS specification.
Optional fields will only be set if the version of the parsed SMBIOS table is high enough to have defined the field.
Fields
handle: u16manufacturer: &'buffer strproduct: &'buffer strversion: &'buffer strserial: &'buffer strasset: Option<&'buffer str>feature_flags: Option<BaseBoardFlags>location_in_chassis: Option<&'buffer str>chassis_handle: Option<u16>board_type: Option<BoardType>Trait Implementations
impl<'buffer> Clone for BaseBoard<'buffer>[src]
impl<'buffer> Debug for BaseBoard<'buffer>[src]
impl<'buffer> Eq for BaseBoard<'buffer>[src]
impl<'buffer> Hash for BaseBoard<'buffer>[src]
fn hash<__H: Hasher>(&self, state: &mut __H)[src]
pub fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
H: Hasher,
impl<'buffer> PartialEq<BaseBoard<'buffer>> for BaseBoard<'buffer>[src]
fn eq(&self, other: &BaseBoard<'buffer>) -> bool[src]
fn ne(&self, other: &BaseBoard<'buffer>) -> bool[src]
impl<'buffer> StructuralEq for BaseBoard<'buffer>[src]
impl<'buffer> StructuralPartialEq for BaseBoard<'buffer>[src]