Struct dmidecode::enclosure::Enclosure [−][src]
System Enclosure or Chassis structure
Fields
handle: u16Specifies the structure’s handle
manufacturer: &'buffer strManufacturer string is non-null
chassis_lock: boolChassis lock is present
enclosure_type: EnclosureTypeType field identifies the type of enclosure. (Unknown is disallowed.)
version: &'buffer strVersion
serial_number: &'buffer strSerial Number
asset_tag_number: &'buffer strAsset Tag Number
boot_up_state: Option<State>State of the enclosure when it was last booted;
power_supply_state: Option<State>State of the enclosure’s power supply (or supplies) when last booted
thermal_state: Option<State>Thermal state of the enclosure when last booted
security_status: Option<SecurityStatus>Physical security status of the enclosure when last booted
oem_defined: Option<u32>OEM- or BIOS vendor-specific information
height: Option<u8>Height of the enclosure , in ’U’s A U is a standard unit of measure for the height of a rack or rack-mountable component and is equal to 1.75 inches or 4.445 cm. A value of 00h indicates that the enclosure height is unspecified.
power_cords_number: Option<u8>Number of power cords associated with the enclosure or chassis A value of 00h indicates that the number is unspecified.
contained_elements: Option<ContainedElements<'buffer>>Each Contained Element record consists of sub-fields that further describe elements contained by the chassis
sku_number: Option<&'buffer str>Number of null-terminated string describing the chassis or enclosure SKU number