BIOS Information (Type 0)
BIOS Information structure
Structs
- Bios
- BIOS Information
- Bios
Revision - BIOS Revision assembled from System BIOS Major Release and System BIOS Minor Release fields
- Characteristics
- BIOS Characteristics
- Characteristics
Extension1 - BIOS Characteristics Extension Byte 1 layout. This information, available for SMBIOS 946 version 2.1 and later, appears at offset 12h within the BIOS Information structure.
- Characteristics
Extension2 - BIOS Characteristics for Extension Byte 2 layout. This information, available for 950 SMBIOS version 2.4 and later, appears at offset 13h within the BIOS Information structure.
- Firmware
Revision - Firmware Revision assembled from Embedded Controller Firmware Major Release and Embedded Controller Firmware Minor Release fields
- RomSize
- The size of the physical device containing the BIOS.