Memory Array Mapped Address (Type 19)
This structure provides the address mapping for a Physical Memory Array. One structure is present for each contiguous address range described.
Structs
- Memory
Array Mapped Address - Main struct for Memory Array Mapped Address (Type 19)