pub struct MemoryArrayMappedAddress {
pub handle: u16,
pub starting_address: u32,
pub ending_address: u32,
pub memory_array_handle: u16,
pub partition_width: u8,
pub extended_starting_address: Option<u64>,
pub extended_ending_address: Option<u64>,
}Expand description
Main struct for Memory Array Mapped Address (Type 19)
Fields
handle: u16Specifies the structure’s handle
starting_address: u32Physical address, in kilobytes, of a range of memory mapped to the specified Physical
Memory Array.
When the field value is FFFF FFFFh, the actual address is stored in the Extended Starting
Address field. When this field contains a valid address, Ending Address must also contain a
valid address. When this field contains FFFF FFFFh, Ending Address must also contain FFFF
FFFFh
ending_address: u32Physical ending address of the last kilobyte of a range of addresses mapped to the
specified Physical Memory Array.
When the field value is FFFF FFFFh and the Starting Address field also contains FFFF FFFFh,
the actual address is stored in the Extended Ending Address field. When this field contains
a valid address, Starting Address must also contain a valid address.
memory_array_handle: u16Handle, or instance number, associated with the Physical Memory Array to which this address
range is mapped.
Multiple address ranges can be mapped to a single Physical Memory Array.
partition_width: u8Number of Memory Devices that form a single row of memory for the address partition defined by this structure.
extended_starting_address: Option<u64>Physical address, in bytes, of a range of memory mapped to the specified Physical Memory
Array.
This field is valid when Starting Address contains the value FFFF FFFFh. If Starting
Address contains a value other than FFFF FFFFh, this field contains zeros. When this field
contains a valid address, Extended Ending Address must also contain a valid address.
extended_ending_address: Option<u64>Physical ending address, in bytes, of the last of a range of addresses mapped to the
specified Physical Memory Array.
This field is valid when both Starting Address and Ending Address contain the value FFFF
FFFFh. If Ending Address contains a value other than FFFF FFFFh, this field contains zeros.
When this field contains a valid address, Extended Starting Address must also contain a
valid address.