Memory Device (Type 17)
This structure describes a single memory device that is part of a larger Physical Memory Array (Type 16) structure.
Structs
- Detail
- The memory device details
- Memory
Device - The
Memory Devicetable defined in the SMBIOS specification. - Operating
Modes