Memory Device (Type 17)

This structure describes a single memory device that is part of a larger Physical Memory Array (Type 16) structure.

Structs

The memory device details

The Memory Device table defined in the SMBIOS specification.

Enums