Module dmidecode::structures::port_connector
source · Expand description
Port Connector Information (Type 8)
Information in this structure defines the attributes of a system port connector (for example, parallel, serial, keyboard, or mouse ports). The port’s type and connector information are provided. One structure is present for each port provided by the system.
Structs
- The
Port Connector Informationtable defined in the SMBIOS specification.