Struct dmidecode::structures::port_connector::PortConnector
source · pub struct PortConnector<'a> {
pub handle: u16,
pub internal_reference_designator: &'a str,
pub internal_connector_type: ConnectorType,
pub external_reference_designator: &'a str,
pub external_connector_type: ConnectorType,
pub port_type: PortType,
}Expand description
The Port Connector Information table defined in the SMBIOS specification.
Optional fields will only be set if the version of the parsed SMBIOS table is high enough to have defined the field.
Fields
handle: u16Specifies the structure’s handle
internal_reference_designator: &'a strInternal Reference Designator, that is, internal to the system enclosure
EXAMPLE: ‘J101’, 0
internal_connector_type: ConnectorTypeInternal Connector type
external_reference_designator: &'a strString number for the External Reference Designation external to the system enclosure
EXAMPLE: ‘COM A’, 0
external_connector_type: ConnectorTypeExternal Connector type
port_type: PortTypeDescribes the function of the port