Processor

Struct Processor 

pub struct Processor<'buffer> {
Show 23 fields pub handle: u16, pub socket_designation: &'buffer str, pub processor_type: ProcessorType, pub processor_family: ProcessorFamily, pub processor_manufacturer: &'buffer str, pub processor_id: u64, pub processor_version: &'buffer str, pub voltage: Voltage, pub external_clock: u16, pub max_speed: u16, pub current_speed: u16, pub status: ProcessorStatus, pub processor_upgrade: ProcessorUpgrade, pub l1_cache_handle: Option<u16>, pub l2_cache_handle: Option<u16>, pub l3_cache_handle: Option<u16>, pub serial_number: Option<&'buffer str>, pub asset_tag: Option<&'buffer str>, pub part_number: Option<&'buffer str>, pub core_count: Option<u16>, pub core_enabled: Option<u16>, pub thread_count: Option<u16>, pub processor_characteristics: Option<ProcessorCharacteristics>,
}
The Processor table defined in the SMBIOS specification.

Optional fields will only be set if the version of the parsed SMBIOS table is high enough to have defined the field.

Fields

handle: u16socket_designation: &'buffer str

String number for Reference Designation EXAMPLE: ‘J202’,0

processor_type: ProcessorType

Processor Type field

processor_family: ProcessorFamily

Processor Family field

processor_manufacturer: &'buffer str

String number of Processor Manufacturer

processor_id: u64

Raw processor identification data

processor_version: &'buffer str

String number describing the Processor

voltage: Voltage

Voltage

external_clock: u16

External Clock Frequency, in MHz. If the value is unknown, the field is set to 0.

max_speed: u16

Maximum processor speed (in MHz) supported by the system for this processor socket

current_speed: u16

This field identifies the processor’s speed at system boot; the processor may support more than one speed.

status: ProcessorStatus

Status

processor_upgrade: ProcessorUpgrade

Processor Upgrade field

l1_cache_handle: Option<u16>

Handle of a Cache Information structure that defines the attributes of the primary (Level 1) cache for this processor

l2_cache_handle: Option<u16>

Handle of a Cache Information structure that defines the attributes of the secondary (Level 2) cache for this processor

l3_cache_handle: Option<u16>

Handle of a Cache Information structure that defines the attributes of the tertiary (Level 3) cache for this processor

serial_number: Option<&'buffer str>

String number for the serial number of this processor

asset_tag: Option<&'buffer str>

String number for the asset tag of this processor

part_number: Option<&'buffer str>

String number for the part number of this processor

core_count: Option<u16>

Number of cores per processor socket

core_enabled: Option<u16>

Number of enabled cores per processor socket

thread_count: Option<u16>

Number of threads per processor socket

processor_characteristics: Option<ProcessorCharacteristics>

Defines which functions the processor supports